@@ -45,6 +45,7 @@ module ExampleAppHooks
     def final_tasks
       copy_file 'spec/verify_no_active_record_spec.rb'
       copy_file 'spec/verify_no_fixture_setup_spec.rb'
+      copy_file 'spec/verify_fixture_file_upload_spec.rb'
     end
 
     def skip_active_record?
@@ -84,7 +85,10 @@ setup_tasks
 generate('rspec:install')
 generate('controller wombats index') # plural
 generate('controller welcome index') # singular
-generate('rspec:request wombats')
+
+# request specs are now the default
+generate('rspec:controller wombats --no-request-specs --controller-specs --no-view-specs')
+
 generate('integration_test widgets')
 generate('mailer Notifications signup')
 
@@ -104,6 +108,12 @@ using_source_path(File.expand_path(__dir__)) do
   copy_file 'spec/features/model_mocks_integration_spec.rb'
 end
 
+begin
+  require 'action_mailbox'
+  run('rails action_mailbox:install')
+rescue LoadError
+end
+
 begin
   require 'active_job'
   generate('job upload_backups')
