@@ -2,23 +2,41 @@ require 'aruba/cucumber'
 require 'fileutils'
 
 module ArubaExt
-  def run(cmd, timeout = nil)
+  def run_command(cmd, timeout = nil)
     exec_cmd = cmd =~ /^rspec/ ? "bin/#{cmd}" : cmd
-    super(exec_cmd, timeout)
+    unset_bundler_env_vars
+    # Ensure the correct Gemfile and binstubs are found
+    in_current_directory do
+      with_unbundled_env do
+        super(exec_cmd, timeout)
+      end
+    end
   end
-  # This method over rides Aruba 0.5.4 implementation so that we can reset Bundler to use the sample app Gemfile
-  def in_current_dir(&block)
-    Bundler.with_clean_env do
-      _mkdir(current_dir)
-      Dir.chdir(current_dir, &block)
+
+  def unset_bundler_env_vars
+    empty_env = with_environment { with_unbundled_env { ENV.to_h } }
+    aruba_env = aruba.environment.to_h
+    (aruba_env.keys - empty_env.keys).each do |key|
+      delete_environment_variable key
+    end
+    empty_env.each do |k, v|
+      set_environment_variable k, v
+    end
+  end
+
+  def with_unbundled_env
+    if Bundler.respond_to?(:with_unbundled_env)
+      Bundler.with_unbundled_env { yield }
+    else
+      Bundler.with_clean_env { yield }
     end
   end
 end
 
 World(ArubaExt)
 
-Before do
-  @aruba_timeout_seconds = 30
+Aruba.configure do |config|
+  config.exit_timeout = 30
 end
 
 unless File.directory?('./tmp/example_app')
@@ -40,6 +58,7 @@ Before do
   helpers = %w[spec/spec_helper.rb spec/rails_helper.rb]
   Dir["#{aruba_dir}/spec/*"].each do |path|
     next if helpers.any? { |helper| path.end_with?(helper) }
+
     FileUtils.rm_rf(path)
   end
 end
