@@ -5,10 +5,10 @@ module Rspec
     # @private
     class ModelGenerator < Base
       argument :attributes,
-               :type => :array,
-               :default => [],
-               :banner => "field:type field:type"
-      class_option :fixture, :type => :boolean
+               type: :array,
+               default: [],
+               banner: "field:type field:type"
+      class_option :fixture, type: :boolean
 
       def create_model_spec
         template_file = File.join(
@@ -23,7 +23,8 @@ module Rspec
 
       def create_fixture_file
         return unless missing_fixture_replacement?
-        template 'fixtures.yml', File.join('spec/fixtures', "#{table_name}.yml")
+
+        template 'fixtures.yml', File.join('spec/fixtures', class_path, "#{(pluralize_table_names? ? plural_file_name : file_name)}.yml")
       end
 
     private
