@@ -1,3 +1,4 @@
+# rubocop: disable Metrics/ModuleLength
 module RSpec
   module Rails
     # Fake class to document RSpec Rails configuration options. In practice,
@@ -55,7 +56,7 @@ module RSpec
     end
 
     # @private
-    def self.initialize_configuration(config) # rubocop:disable Metrics/MethodLength
+    def self.initialize_configuration(config) # rubocop:disable Metrics/MethodLength,Metrics/CyclomaticComplexity
       config.backtrace_exclusion_patterns << /vendor\//
       config.backtrace_exclusion_patterns << %r{lib/rspec/rails}
 
@@ -79,10 +80,8 @@ module RSpec
       #   `RSpec::Rails::FixtureSupport` directly instead
       config.include RSpec::Rails::FixtureSupport
 
-      if ::Rails::VERSION::STRING > '5'
-        config.add_setting :file_fixture_path, default: 'spec/fixtures/files'
-        config.include RSpec::Rails::FileFixtureSupport
-      end
+      config.add_setting :file_fixture_path, default: 'spec/fixtures/files'
+      config.include RSpec::Rails::FileFixtureSupport
 
       # Add support for fixture_path on fixture_file_upload
       config.include RSpec::Rails::FixtureFileUploadSupport
@@ -105,7 +104,41 @@ module RSpec
         end
 
         def render_views?
-          rendering_views
+          rendering_views?
+        end
+
+        undef :rendering_views? if respond_to?(:rendering_views?)
+        def rendering_views?
+          !!rendering_views
+        end
+
+        # Define boolean predicates rather than relying on rspec-core due
+        # to the bug fix in rspec/rspec-core#2736, note some of these
+        # predicates are a bit nonsensical, but they exist for backwards
+        # compatibility, we can tidy these up in `rspec-rails` 5.
+        undef :fixture_path? if respond_to?(:fixture_path?)
+        def fixture_path?
+          !!fixture_path
+        end
+
+        undef :global_fixtures? if respond_to?(:global_fixtures?)
+        def global_fixtures?
+          !!global_fixtures
+        end
+
+        undef :infer_base_class_for_anonymous_controllers? if respond_to?(:infer_base_class_for_anonymous_controllers?)
+        def infer_base_class_for_anonymous_controllers?
+          !!infer_base_class_for_anonymous_controllers
+        end
+
+        undef :use_instantiated_fixtures? if respond_to?(:use_instantiated_fixtures?)
+        def use_instantiated_fixtures?
+          !!use_instantiated_fixtures
+        end
+
+        undef :use_transactional_fixtures? if respond_to?(:use_transactional_fixtures?)
+        def use_transactional_fixtures?
+          !!use_transactional_fixtures
         end
 
         def infer_spec_type_from_file_location!
@@ -156,3 +189,4 @@ module RSpec
     initialize_configuration RSpec.configuration
   end
 end
+# rubocop: enable Metrics/ModuleLength
