@@ -1,8 +1,10 @@
 # Generators are not automatically loaded by Rails
 require 'generators/rspec/scaffold/scaffold_generator'
 require 'support/generators'
+require 'rspec/support/spec/in_sub_process'
 
 RSpec.describe Rspec::Generators::ScaffoldGenerator, type: :generator do
+  include RSpec::Support::InSubProcess
   setup_default_destination
 
   describe 'standard request specs' do
@@ -39,6 +41,16 @@ RSpec.describe Rspec::Generators::ScaffoldGenerator, type: :generator do
       it { is_expected.to contain('renders a JSON response with the post') }
       it { is_expected.to contain('renders a JSON response with errors for the post') }
     end
+
+    describe 'in an engine' do
+      it 'generates files with Engine url_helpers' do
+        in_sub_process do
+          allow_any_instance_of(::Rails::Generators::NamedBase).to receive(:mountable_engine?).and_return(true)
+          run_generator %w[posts --request_specs]
+          is_expected.to contain('Engine.routes.url_helpers')
+        end
+      end
+    end
   end
 
   describe 'standard controller spec' do
@@ -155,35 +167,18 @@ RSpec.describe Rspec::Generators::ScaffoldGenerator, type: :generator do
       it { is_expected.to contain('assert_select "tr>td", text: 3.5.to_s, count: 2') }
     end
 
-    if Rails.version.to_f >= 5.1
-      describe 'with reference attribute' do
-        before { run_generator %w[posts title:string author:references] }
-        describe 'edit' do
-          subject { file("spec/views/posts/edit.html.erb_spec.rb") }
-          it { is_expected.to contain(/assert_select "input\[name=\?\]", "post\[author_id\]/) }
-          it { is_expected.to contain(/assert_select "input\[name=\?\]", "post\[title\]/) }
-        end
-
-        describe 'new' do
-          subject { file("spec/views/posts/new.html.erb_spec.rb") }
-          it { is_expected.to contain(/assert_select "input\[name=\?\]", "post\[author_id\]"/) }
-          it { is_expected.to contain(/assert_select "input\[name=\?\]", "post\[title\]/) }
-        end
+    describe 'with reference attribute' do
+      before { run_generator %w[posts title:string author:references] }
+      describe 'edit' do
+        subject { file("spec/views/posts/edit.html.erb_spec.rb") }
+        it { is_expected.to contain(/assert_select "input\[name=\?\]", "post\[author_id\]/) }
+        it { is_expected.to contain(/assert_select "input\[name=\?\]", "post\[title\]/) }
       end
-    else
-      describe 'with reference attribute' do
-        before { run_generator %w[posts title:string author:references] }
-        describe 'edit' do
-          subject { file("spec/views/posts/edit.html.erb_spec.rb") }
-          it { is_expected.to contain(/assert_select "input#(.*)_author_id\[name=\?\]", "\1\[author_id\]/) }
-          it { is_expected.to contain(/assert_select "input#(.*)_title\[name=\?\]", "\1\[title\]/) }
-        end
 
-        describe 'new' do
-          subject { file("spec/views/posts/new.html.erb_spec.rb") }
-          it { is_expected.to contain(/assert_select "input#(.*)_author_id\[name=\?\]", "\1\[author_id\]"/) }
-          it { is_expected.to contain(/assert_select "input#(.*)_title\[name=\?\]", "\1\[title\]/) }
-        end
+      describe 'new' do
+        subject { file("spec/views/posts/new.html.erb_spec.rb") }
+        it { is_expected.to contain(/assert_select "input\[name=\?\]", "post\[author_id\]"/) }
+        it { is_expected.to contain(/assert_select "input\[name=\?\]", "post\[title\]/) }
       end
     end
 
