@@ -2,12 +2,12 @@
 require 'generators/rspec/view/view_generator'
 require 'support/generators'
 
-RSpec.describe Rspec::Generators::ViewGenerator, :type => :generator do
+RSpec.describe Rspec::Generators::ViewGenerator, type: :generator do
   setup_default_destination
 
   describe 'with default template engine' do
     it 'generates a spec for the supplied action' do
-      run_generator %w(posts index)
+      run_generator %w[posts index]
       file('spec/views/posts/index.html.erb_spec.rb').tap do |f|
         expect(f).to contain(/require 'rails_helper'/)
         expect(f).to contain(/^RSpec.describe \"posts\/index\", #{type_metatag(:view)}/)
@@ -16,7 +16,7 @@ RSpec.describe Rspec::Generators::ViewGenerator, :type => :generator do
 
     describe 'with a nested resource' do
       it 'generates a spec for the supplied action' do
-        run_generator %w(admin/posts index)
+        run_generator %w[admin/posts index]
         file('spec/views/admin/posts/index.html.erb_spec.rb').tap do |f|
           expect(f).to contain(/require 'rails_helper'/)
           expect(f).to contain(/^RSpec.describe \"admin\/posts\/index\", #{type_metatag(:view)}/)
@@ -27,7 +27,7 @@ RSpec.describe Rspec::Generators::ViewGenerator, :type => :generator do
 
   describe 'with a specified template engine' do
     it 'generates a spec for the supplied action' do
-      run_generator %w(posts index --template_engine haml)
+      run_generator %w[posts index --template_engine haml]
       file('spec/views/posts/index.html.haml_spec.rb').tap do |f|
         expect(f).to contain(/require 'rails_helper'/)
         expect(f).to contain(/^RSpec.describe \"posts\/index\", #{type_metatag(:view)}/)
