@@ -33,6 +33,8 @@ if RSpec::Rails::FeatureCheck.has_active_job?
 end
 
 RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_active_job? do
+  include ActiveSupport::Testing::TimeHelpers
+
   around do |example|
     original_logger = ActiveJob::Base.logger
     ActiveJob::Base.logger = Logger.new(nil) # Silence messages "[ActiveJob] Enqueued ...".
@@ -223,6 +225,25 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       }.to have_enqueued_job.at(time)
     end
 
+    it "works with time offsets" do
+      # note that Time.current does not replicate Rails behavior for 5 seconds from now.
+      time = Time.current.change(usec: 0)
+      travel_to time do
+        expect { hello_job.set(wait: 5).perform_later }.to have_enqueued_job.at(time + 5)
+      end
+    end
+
+    it "warns when time offsets are inprecise" do
+      expect(RSpec).to receive(:warn_with).with(/precision error/)
+
+      time = Time.current.change(usec: 550)
+      travel_to time do
+        expect {
+          expect { hello_job.set(wait: 5).perform_later }.to have_enqueued_job.at(time + 5)
+        }.to raise_error(/expected to enqueue exactly 1 jobs/)
+      end
+    end
+
     it "accepts composable matchers as an at date" do
       future = 1.minute.from_now
       slightly_earlier = 58.seconds.from_now
@@ -681,4 +702,16 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       }.to raise_error(/expected to perform exactly 1 jobs, but performed 0/)
     end
   end
+
+  describe 'Active Job test helpers' do
+    include ActiveJob::TestHelper
+
+    it 'does not raise that "assert_nothing_raised" is undefined' do
+      expect {
+        perform_enqueued_jobs do
+          :foo
+        end
+      }.to_not raise_error
+    end
+  end
 end
