@@ -1,18 +1,18 @@
 ActiveRecord::Base.establish_connection(
-  :adapter => 'sqlite3',
-  :database => ':memory:'
+  adapter: 'sqlite3',
+  database: ':memory:'
 )
 
 module Connections
   def self.extended(host)
-    host.connection.execute <<-eosql
+    host.connection.execute <<-EOSQL
       CREATE TABLE #{host.table_name} (
         #{host.primary_key} integer PRIMARY KEY AUTOINCREMENT,
         associated_model_id integer,
         mockable_model_id integer,
         nonexistent_model_id integer
       )
-    eosql
+    EOSQL
 
     host.reset_column_information
   end
@@ -34,7 +34,7 @@ end
 class AssociatedModel < ActiveRecord::Base
   extend Connections
   belongs_to :mockable_model
-  belongs_to :nonexistent_model, :class_name => "Other"
+  belongs_to :nonexistent_model, class_name: "Other"
 end
 
 class AlternatePrimaryKeyModel < ActiveRecord::Base
