@@ -1,6 +1,6 @@
 require 'pathname'
 
-shared_examples_for "an rspec-rails example group mixin" do |type, *paths|
+RSpec.shared_examples_for "an rspec-rails example group mixin" do |type, *paths|
   let(:mixin) { described_class }
 
   def define_group_in(path, group_definition)
@@ -27,10 +27,6 @@ shared_examples_for "an rspec-rails example group mixin" do |type, *paths|
     end
   end
 
-  around(:example) do |ex|
-    with_isolated_config(&ex)
-  end
-
   it "adds does not add `:type` metadata on inclusion" do
     mixin = self.mixin
     group = RSpec.describe { include mixin }
